@@ -163,11 +163,11 @@ zenity_notification_handle_stdin (GIOChannel *channel,
         if (!g_utf8_validate (value, -1, NULL)) {
           g_warning ("Invalid UTF-8 in input!");
         } else if (notify_is_initted ()) {
-          GError *error = NULL;
           NotifyNotification *notif;
           const gchar *icon = NULL;
           gchar *freeme = NULL;
           gchar *message;
+          error = NULL;
 
           message = g_strcompress (value);
 
@@ -280,6 +280,11 @@ zenity_notification (ZenityData *data, ZenityNotificationData *notification_data
 
   /* Show icon and wait */
   gtk_status_icon_set_visible (status_icon, TRUE);
+
+  if(data->timeout_delay > 0) {
+    g_timeout_add (data->timeout_delay * 1000, (GSourceFunc) zenity_util_timeout_handle, NULL);
+  }
+
   gtk_main ();
 
   /* Cleanup */
