@@ -15,6 +15,7 @@ GladeXML*       zenity_util_load_glade_file               (const gchar    *widge
 gchar *         zenity_util_strip_newline                 (gchar          *string);
 gboolean        zenity_util_fill_file_buffer              (GtkTextBuffer  *buffer, 
                                                            const gchar    *filename);
+const gchar *   zenity_util_stock_from_filename		  (const gchar    *filename);
 void		zenity_util_set_window_icon		  (GtkWidget      *widget,
 							   const gchar	  *filename,
 							   const gchar	  *default_file);
@@ -22,11 +23,13 @@ void            zenity_util_set_window_icon_from_stock    (GtkWidget      *widge
 							   const gchar    *filename,
                                                            const gchar    *default_stock_id);
 GdkPixbuf *	zenity_util_pixbuf_new_from_file	  (GtkWidget	  *widget,
-							   gchar	  *filename);
+							   const gchar	  *filename);
 void		zenity_util_show_help                     (GError        **error);
 gint		zenity_util_return_exit_code 		  (ZenityExitCode value);                      
 void            zenity_util_show_dialog                   (GtkWidget      *widget);
-                               
+
+gboolean        zenity_util_timeout_handle                (void);
+
 G_END_DECLS
 
 #endif /* UTIL_H */
